TyRgbaColor

Struct TyRgbaColor 

pub struct TyRgbaColor<T = f32> {
    pub r: T,
    pub g: T,
    pub b: T,
    pub a: T,
}
An RGBA color generic over its component type T, each component in the range [0, 1].

The component type defaults to f32, so TyRgbaColor is the f32 color; see TyRgbaColorF32 and TyRgbaColorF64 for the common instantiations.

Fields

r: T

The red component, in the range [0, 1].

g: T

The green component, in the range [0, 1].

b: T

The blue component, in the range [0, 1].

a: T

The alpha component, in the range [0, 1].

Implementations

Source

impl<T> TyRgbaColor<T>

pub fn new(r: T, g: T, b: T, a: T) -> Self

Creates a new color from r, g, b, and a components.